@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -14,9 +14,14 @@ export interface ClusterInfo {
   applications: ApplicationInfo[];
 }
 
+export enum ApplicationId {
+  CLUSTER_CONSOLE = 'cluster-console',
+}
+
 export interface ApplicationInfo {
   url: string;
   title: string;
   icon: string;
   group?: string;
+  id?: ApplicationId;
 }
