@@ -19,7 +19,6 @@ import { DockerConfigApiService } from '../services/dockerConfigApi';
 import { EventApiService } from '../services/eventApi';
 import { KubeConfigApiService } from '../services/kubeConfigApi';
 import { LogsApiService } from '../services/logsApi';
-import { NamespaceApiService } from '../services/namespaceApi';
 import { PodApiService } from '../services/podApi';
 import { ServerConfigApiService } from '../services/serverConfigApi';
 import { UserProfileApiService } from '../services/userProfileApi';
@@ -47,7 +46,6 @@ describe('DevWorkspace client', () => {
     expect(client.eventApi).toBeInstanceOf(EventApiService);
     expect(client.kubeConfigApi).toBeInstanceOf(KubeConfigApiService);
     expect(client.logsApi).toBeInstanceOf(LogsApiService);
-    expect(client.namespaceApi).toBeInstanceOf(NamespaceApiService);
     expect(client.podApi).toBeInstanceOf(PodApiService);
     expect(client.serverConfigApi).toBeInstanceOf(ServerConfigApiService);
     expect(client.userProfileApi).toBeInstanceOf(UserProfileApiService);
