@@ -18,7 +18,7 @@ import { EventApiService } from './services/eventApi';
 import { KubeConfigApiService } from './services/kubeConfigApi';
 import { PodmanApiService } from './services/podmanApi';
 import { LogsApiService } from './services/logsApi';
-import { NamespaceApiService } from './services/namespaceApi';
+import { PersonalAccessTokenService } from './services/personalAccessTokenApi';
 import { PodApiService } from './services/podApi';
 import { ServerConfigApiService } from './services/serverConfigApi';
 import { UserProfileApiService } from './services/userProfileApi';
@@ -31,7 +31,7 @@ import {
   IEventApi,
   IKubeConfigApi,
   ILogsApi,
-  INamespaceApi,
+  IPersonalAccessTokenApi,
   IPodApi,
   IServerConfigApi,
   IUserProfileApi,
@@ -78,10 +78,6 @@ export class DevWorkspaceClient implements IDevWorkspaceClient {
     return new PodmanApiService(this.kubeConfig);
   }
 
-  get namespaceApi(): INamespaceApi {
-    return new NamespaceApiService(this.kubeConfig);
-  }
-
   get userProfileApi(): IUserProfileApi {
     return new UserProfileApiService(this.kubeConfig);
   }
@@ -89,4 +85,8 @@ export class DevWorkspaceClient implements IDevWorkspaceClient {
   get logsApi(): ILogsApi {
     return new LogsApiService(this.kubeConfig);
   }
+
+  get personalAccessTokenApi(): IPersonalAccessTokenApi {
+    return new PersonalAccessTokenService(this.kubeConfig);
+  }
 }
