@@ -22,6 +22,9 @@ import {
 import { createError } from './helpers/createError';
 import { CustomObjectAPI, prepareCustomObjectAPI } from './helpers/prepareCustomObjectAPI';
 import { startTimeoutSeconds } from '../../constants/server-config';
+import { isLocalRun } from '../../localRun';
+import { readFileSync } from 'fs';
+import path from 'path';
 
 const CUSTOM_RESOURCE_DEFINITIONS_API_ERROR_LABEL = 'CUSTOM_RESOURCE_DEFINITIONS_API_ERROR';
 
@@ -44,6 +47,11 @@ export class ServerConfigApiService implements IServerConfigApi {
   }
 
   async fetchCheCustomResource(): Promise<CustomResourceDefinition> {
+    if (isLocalRun()) {
+      return JSON.parse(
+        readFileSync(path.join(__dirname, '../../../../run/.custom-resources')).toString(),
+      );
+    }
     if (!this.env.NAME || !this.env.NAMESPACE) {
       throw createError(
         undefined,
@@ -98,6 +106,14 @@ export class ServerConfigApiService implements IServerConfigApi {
     return cheCustomResource.spec.devEnvironments?.defaultPlugins || [];
   }
 
+  getDefaultDevfileRegistryUrl(cheCustomResource: CustomResourceDefinition): string {
+    return cheCustomResource.status?.devfileRegistryURL || '';
+  }
+
+  getDefaultPluginRegistryUrl(cheCustomResource: CustomResourceDefinition): string {
+    return cheCustomResource.status?.pluginRegistryURL || '';
+  }
+
   getDefaultEditor(cheCustomResource: CustomResourceDefinition): string | undefined {
     return (
       cheCustomResource.spec.devEnvironments?.defaultEditor ||
@@ -138,6 +154,16 @@ export class ServerConfigApiService implements IServerConfigApi {
     return cheCustomResource.spec.devEnvironments?.storage?.pvcStrategy;
   }
 
+  getInternalRegistryDisableStatus(cheCustomResource: CustomResourceDefinition): boolean {
+    return cheCustomResource.spec.components?.devfileRegistry?.disableInternalRegistry || false;
+  }
+
+  getExternalDevfileRegistries(
+    cheCustomResource: CustomResourceDefinition,
+  ): api.IExternalDevfileRegistry[] {
+    return cheCustomResource.spec.components?.devfileRegistry?.externalDevfileRegistries || [];
+  }
+
   getDashboardWarning(cheCustomResource: CustomResourceDefinition): string | undefined {
     // Return the message if it is defined and the show flag is true
     if (cheCustomResource.spec.components?.dashboard?.headerMessage?.text) {
