@@ -36,13 +36,6 @@ export interface IDockerConfigApi {
   update(namespace: string, dockerCfg: api.IDockerConfig): Promise<api.IDockerConfig>;
 }
 
-export interface INamespaceApi {
-  /**
-   * Returns user namespaces
-   */
-  getNamespaces(token: string): Promise<Array<string>>;
-}
-
 export interface IDevWorkspaceApi extends IWatcherService<api.webSocket.SubscribeParams> {
   /**
    * Get the DevWorkspace with given namespace in the specified namespace
@@ -114,6 +107,10 @@ export type CustomResourceDefinition = k8s.V1CustomResourceDefinition & {
     devEnvironments?: CustomResourceDefinitionSpecDevEnvironments;
     components?: CustomResourceDefinitionSpecComponents;
   };
+  status: {
+    devfileRegistryURL: string;
+    pluginRegistryURL: string;
+  };
 };
 
 export type CustomResourceDefinitionSpecDevEnvironments = {
@@ -147,6 +144,10 @@ export type CustomResourceDefinitionSpecComponents = {
   pluginRegistry?: {
     openVSXURL?: string;
   };
+  devfileRegistry: {
+    disableInternalRegistry?: boolean;
+    externalDevfileRegistries?: api.IExternalDevfileRegistry[];
+  };
 };
 
 export interface IServerConfigApi {
@@ -167,6 +168,14 @@ export interface IServerConfigApi {
    * Returns default plugins
    */
   getDefaultPlugins(cheCustomResource: CustomResourceDefinition): api.IWorkspacesDefaultPlugins[];
+  /**
+   * Returns the default devfile registry URL.
+   */
+  getDefaultDevfileRegistryUrl(cheCustomResource: CustomResourceDefinition): string;
+  /**
+   * Returns the plugin registry URL.
+   */
+  getDefaultPluginRegistryUrl(cheCustomResource: CustomResourceDefinition): string;
   /**
    * Returns the default editor to workspace create with. It could be a plugin ID or a URI.
    */
@@ -180,6 +189,16 @@ export interface IServerConfigApi {
    * Returns the openVSX URL.
    */
   getOpenVSXURL(cheCustomResource: CustomResourceDefinition): string;
+  /**
+   * Returns the internal registry disable status.
+   */
+  getInternalRegistryDisableStatus(cheCustomResource: CustomResourceDefinition): boolean;
+  /**
+   * Returns the external devfile registries.
+   */
+  getExternalDevfileRegistries(
+    cheCustomResource: CustomResourceDefinition,
+  ): api.IExternalDevfileRegistry[];
   /**
    * Returns the PVC strategy if it is defined.
    */
@@ -236,14 +255,44 @@ export interface IUserProfileApi {
   getUserProfile(namespace: string): Promise<api.IUserProfile | undefined>;
 }
 
+export interface IPersonalAccessTokenApi {
+  /**
+   * Reads all the PAT secrets from the specified namespace.
+   */
+  listInNamespace(namespace: string): Promise<Array<api.PersonalAccessToken>>;
+
+  /**
+   * Creates a PAT secret.
+   */
+  create(
+    namespace: string,
+    personalAccessToken: api.PersonalAccessToken,
+  ): Promise<api.PersonalAccessToken>;
+
+  /**
+   * "Updates" an existing PAT secret.
+   */
+  replace(
+    namespace: string,
+    personalAccessToken: api.PersonalAccessToken,
+  ): Promise<api.PersonalAccessToken>;
+
+  /**
+   * Deletes a PAT secret.
+   */
+  delete(namespace: string, name: string): Promise<void>;
+}
+
 export interface IDevWorkspaceClient {
-  eventApi: IEventApi;
-  devworkspaceApi: IDevWorkspaceApi;
   devWorkspaceTemplateApi: IDevWorkspaceTemplateApi;
+  devworkspaceApi: IDevWorkspaceApi;
   dockerConfigApi: IDockerConfigApi;
-  serverConfigApi: IServerConfigApi;
+  eventApi: IEventApi;
   kubeConfigApi: IKubeConfigApi;
-  namespaceApi: INamespaceApi;
+  logsApi: ILogsApi;
+  personalAccessTokenApi: IPersonalAccessTokenApi;
+  podApi: IPodApi;
+  serverConfigApi: IServerConfigApi;
   userProfileApi: IUserProfileApi;
 }
 
