@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,6 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import { ApplicationId } from '@eclipse-che/common';
 import { FastifyInstance } from 'fastify';
 import { baseApiPath } from '../../../constants/config';
 import { setup, teardown } from '../../../helpers/tests/appBuilder';
@@ -40,6 +41,7 @@ describe('Cluster Info Route', () => {
           icon: `${clusterConsoleUrl}/static/assets/redhat.svg`,
           title: 'OpenShift console',
           url: clusterConsoleUrl,
+          id: ApplicationId.CLUSTER_CONSOLE,
         },
       ],
     });
