@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -93,7 +93,7 @@ describe('Quick Add page', () => {
     devfileButton.click();
 
     expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(dummyDevfile, {
-      stackName: 'dummyStackName',
+      factoryId: 'dummyStackName',
     });
   });
 
