@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -19,6 +19,8 @@ export async function fetchClusterConfig(): Promise<ClusterConfig> {
     const response = await axios.get(`${prefix}/cluster-config`);
     return response.data;
   } catch (e) {
-    throw `Failed to fetch cluster configuration. ${common.helpers.errors.getMessage(e)}`;
+    throw new Error(
+      `Failed to fetch cluster configuration. ${common.helpers.errors.getMessage(e)}`,
+    );
   }
 }
