@@ -79,9 +79,9 @@ export function isDevWorkspaceStatus(status: unknown): status is DevWorkspaceSta
 export type CreateWorkspaceTab = 'quick-add' | 'custom-workspace';
 
 export enum LoaderTab {
-  Progress = 0,
-  Logs = 1,
-  Events = 2,
+  Progress = 'Progress',
+  Logs = 'Logs',
+  Events = 'Events',
 }
 
 export enum WorkspaceDetailsTab {
@@ -101,7 +101,7 @@ export enum WorkspaceAction {
   ADD_PROJECT = 'Add Project',
   ADD_CUSTOM_WORKSPACE = 'Add Workspace',
   RESTART_WORKSPACE = 'Restart Workspace',
-  EDIT_WORKSPACE = 'Workspace Details',
+  WORKSPACE_DETAILS = 'Workspace Details',
 }
 
-export type UserPreferencesTab = 'container-registries' | 'git-services';
+export type UserPreferencesTab = 'container-registries' | 'git-services' | 'personal-access-tokens';
