@@ -13,7 +13,6 @@
 import devfileApi, { isDevfileV2, isDevWorkspace } from '../devfileApi';
 import { DEVWORKSPACE_UPDATING_TIMESTAMP_ANNOTATION } from '../devfileApi/devWorkspace/metadata';
 import { DEVWORKSPACE_STORAGE_TYPE_ATTR } from '../devfileApi/devWorkspace/spec/template';
-import getWorkspaceLogs, { getWorkspaceErrors } from '../helpers/getWorkspaceLogs';
 import { DeprecatedWorkspaceStatus, DevWorkspaceStatus, WorkspaceStatus } from '../helpers/types';
 import {
   devfileToDevWorkspace,
@@ -41,10 +40,9 @@ export interface Workspace {
   readonly isStopping: boolean;
   readonly isRunning: boolean;
   readonly hasError: boolean;
+  readonly error: string | undefined;
   readonly isDevWorkspace: boolean;
   readonly isDeprecated: boolean;
-  readonly logs: string[];
-  readonly errorLogs: string[];
 }
 
 export class WorkspaceAdapter<T extends devfileApi.DevWorkspace> implements Workspace {
@@ -190,6 +188,13 @@ export class WorkspaceAdapter<T extends devfileApi.DevWorkspace> implements Work
     );
   }
 
+  get error(): string | undefined {
+    if (this.hasError === false) {
+      return;
+    }
+    return this.workspace.status?.message;
+  }
+
   get ideUrl(): string | undefined {
     return this.workspace.status?.mainUrl;
   }
@@ -248,14 +253,6 @@ export class WorkspaceAdapter<T extends devfileApi.DevWorkspace> implements Work
   get projects(): string[] {
     return (this.workspace.spec.template.projects || []).map(project => project.name);
   }
-
-  get logs(): string[] {
-    return getWorkspaceLogs(this.workspace);
-  }
-
-  get errorLogs(): string[] {
-    return getWorkspaceErrors(this.workspace);
-  }
 }
 
 export function constructWorkspace<T extends devfileApi.DevWorkspace>(workspace: T): Workspace {
