@@ -47,8 +47,8 @@ import {
 import { DevWorkspaceDefaultPluginsHandler } from './DevWorkspaceDefaultPluginsHandler';
 import { DevWorkspacePlugin } from '../../devfileApi/devWorkspace';
 
-const COMPONENT_UPDATE_POLICY = 'che.eclipse.org/components-update-policy';
-const REGISTRY_URL = 'che.eclipse.org/plugin-registry-url';
+export const COMPONENT_UPDATE_POLICY = 'che.eclipse.org/components-update-policy';
+export const REGISTRY_URL = 'che.eclipse.org/plugin-registry-url';
 
 export const DEVWORKSPACE_NEXT_START_ANNOTATION = 'che.eclipse.org/next-start-cfg';
 
@@ -164,15 +164,8 @@ export class DevWorkspaceClient extends WorkspaceClient {
       devWorkspaceResource.metadata.annotations[DEVWORKSPACE_CHE_EDITOR] = editorId;
     }
 
-    // temporarily remove components as they are not created yet
-    const components = devWorkspaceResource.spec.template.components;
-    devWorkspaceResource.spec.template.components = [];
-
     const { headers, devWorkspace } = await DwApi.createWorkspace(devWorkspaceResource);
 
-    // restore components
-    devWorkspace.spec.template.components = components;
-
     return { headers, devWorkspace };
   }
 
@@ -285,6 +278,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
           value: pluginRegistryUrl,
         });
       }
+
       if (pluginRegistryInternalUrl !== undefined) {
         envs.push({
           name: this.pluginRegistryInternalUrlEnvName,
