@@ -11,11 +11,16 @@
  */
 
 import common, { api, ApplicationId } from '@eclipse-che/common';
+import { dump } from 'js-yaml';
 import { Action, Reducer } from 'redux';
 import { AppThunk } from '../..';
 import { container } from '../../../inversify.config';
-import { injectKubeConfig } from '../../../services/dashboard-backend-client/devWorkspaceApi';
-import { podmanLogin } from '../../../services/dashboard-backend-client/devWorkspaceApi';
+import { FactoryParams } from '../../../services/helpers/factoryFlow/buildFactoryParams';
+import {
+  injectKubeConfig,
+  podmanLogin,
+} from '../../../services/dashboard-backend-client/devWorkspaceApi';
+import { fetchResources } from '../../../services/dashboard-backend-client/devworkspaceResourcesApi';
 import { WebsocketClient } from '../../../services/dashboard-backend-client/websocketClient';
 import devfileApi, { isDevWorkspace } from '../../../services/devfileApi';
 import { devWorkspaceKind } from '../../../services/devfileApi/devWorkspace';
@@ -28,27 +33,29 @@ import { delay } from '../../../services/helpers/delay';
 import { DisposableCollection } from '../../../services/helpers/disposable';
 import { getNewerResourceVersion } from '../../../services/helpers/resourceVersion';
 import { DevWorkspaceStatus } from '../../../services/helpers/types';
+import OAuthService from '../../../services/oauth';
+import { loadResourcesContent } from '../../../services/registry/resources';
 import { WorkspaceAdapter } from '../../../services/workspace-adapter';
 import {
   DevWorkspaceClient,
   DEVWORKSPACE_NEXT_START_ANNOTATION,
+  COMPONENT_UPDATE_POLICY,
+  REGISTRY_URL,
 } from '../../../services/workspace-client/devworkspace/devWorkspaceClient';
+import { getCustomEditor } from '../../../services/workspace-client/helpers';
+import { selectApplications } from '../../ClusterInfo/selectors';
+import { getEditor } from '../../DevfileRegistries/getEditor';
 import { createObject } from '../../helpers';
 import { selectDefaultNamespace } from '../../InfrastructureNamespaces/selectors';
-import { getCustomEditor } from '../../../services/workspace-client/helpers';
 import { AUTHORIZED, SanityCheckAction } from '../../sanityCheckMiddleware';
 import * as DwServerConfigStore from '../../ServerConfig';
-import { selectOpenVSXUrl } from '../../ServerConfig/selectors';
-import { fetchResources } from '../../../services/dashboard-backend-client/devworkspaceResourcesApi';
-import { dump } from 'js-yaml';
-import { loadResourcesContent } from '../../../services/registry/resources';
+import {
+  selectOpenVSXUrl,
+  selectPluginRegistryInternalUrl,
+  selectPluginRegistryUrl,
+} from '../../ServerConfig/selectors';
 import { checkRunningWorkspacesLimit } from './checkRunningWorkspacesLimit';
 import { selectDevWorkspacesResourceVersion } from './selectors';
-import OAuthService from '../../../services/oauth';
-import { FactoryParams } from '../../../containers/Loader/buildFactoryParams';
-import { getEditor } from '../../DevfileRegistries/getEditor';
-import { selectApplications } from '../../ClusterInfo/selectors';
-import { cloneDeep } from 'lodash';
 
 export const onStatusChangeCallbacks = new Map<string, (status: string) => void>();
 
@@ -221,7 +228,7 @@ export const actionCreators: ActionCreators = {
           type: Type.RECEIVE_DEVWORKSPACE_ERROR,
           error: errorMessage,
         });
-        throw errorMessage;
+        throw e;
       }
     },
 
@@ -253,7 +260,7 @@ export const actionCreators: ActionCreators = {
           type: Type.RECEIVE_DEVWORKSPACE_ERROR,
           error: errorMessage,
         });
-        throw errorMessage;
+        throw e;
       }
     },
 
@@ -414,7 +421,7 @@ export const actionCreators: ActionCreators = {
           type: Type.RECEIVE_DEVWORKSPACE_ERROR,
           error: errorMessage,
         });
-        throw errorMessage;
+        throw e;
       }
     },
 
@@ -440,7 +447,7 @@ export const actionCreators: ActionCreators = {
           error: resMessage,
         });
 
-        throw resMessage;
+        throw e;
       }
     },
 
@@ -463,7 +470,7 @@ export const actionCreators: ActionCreators = {
           type: Type.RECEIVE_DEVWORKSPACE_ERROR,
           error: errorMessage,
         });
-        throw errorMessage;
+        throw e;
       }
     },
 
@@ -486,7 +493,7 @@ export const actionCreators: ActionCreators = {
           type: Type.RECEIVE_DEVWORKSPACE_ERROR,
           error: errorMessage,
         });
-        throw errorMessage;
+        throw e;
       }
     },
 
@@ -503,16 +510,12 @@ export const actionCreators: ActionCreators = {
 
       const defaultKubernetesNamespace = selectDefaultNamespace(state);
       const openVSXUrl = selectOpenVSXUrl(state);
+      const pluginRegistryUrl = selectPluginRegistryUrl(state);
+      const pluginRegistryInternalUrl = selectPluginRegistryInternalUrl(state);
+      const cheEditor = editorId ? editorId : state.dwPlugins.defaultEditorName;
       const defaultNamespace = defaultKubernetesNamespace.name;
       try {
-        const cheEditor = editorId ? editorId : devWorkspaceTemplateResource.metadata.name;
-        const pluginRegistryUrl =
-          state.workspacesSettings.settings['cheWorkspacePluginRegistryUrl'];
-        const pluginRegistryInternalUrl =
-          state.workspacesSettings.settings['cheWorkspacePluginRegistryInternalUrl'];
-
-        /* create a new DevWorkspace (without components) */
-
+        /* create a new DevWorkspace */
         const createResp = await getDevWorkspaceClient().createDevWorkspace(
           defaultNamespace,
           devWorkspaceResource,
@@ -545,7 +548,7 @@ export const actionCreators: ActionCreators = {
           clusterConsole,
         );
 
-        /* update the DevWorkspace with components */
+        /* update the DevWorkspace */
 
         const updateResp = await getDevWorkspaceClient().updateDevWorkspace(
           createResp.devWorkspace,
@@ -574,7 +577,7 @@ export const actionCreators: ActionCreators = {
           type: Type.RECEIVE_DEVWORKSPACE_ERROR,
           error: errorMessage,
         });
-        throw errorMessage;
+        throw e;
       }
     },
 
@@ -591,27 +594,36 @@ export const actionCreators: ActionCreators = {
 
       await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
 
-      const pluginRegistryUrl = state.workspacesSettings.settings['cheWorkspacePluginRegistryUrl'];
+      const pluginRegistryUrl = state.dwServerConfig.config.pluginRegistryURL;
       let devWorkspaceResource: devfileApi.DevWorkspace;
       let devWorkspaceTemplateResource: devfileApi.DevWorkspaceTemplate;
       let editorContent: string | undefined;
+      let editorYamlUrl: string | undefined;
       // do we have an optional editor parameter ?
       const editor = attributes.cheEditor;
       if (editor) {
         const response = await getEditor(editor, dispatch, getState, pluginRegistryUrl);
         if (response.content) {
           editorContent = response.content;
+          editorYamlUrl = response.editorYamlUrl;
         } else {
           throw new Error(response.error);
         }
       } else {
         // do we have the custom editor in `.che/che-editor.yaml` ?
-        editorContent = await getCustomEditor(
-          pluginRegistryUrl,
-          optionalFilesContent,
-          dispatch,
-          getState,
-        );
+        try {
+          editorContent = await getCustomEditor(
+            pluginRegistryUrl,
+            optionalFilesContent,
+            dispatch,
+            getState,
+          );
+          if (!editorContent) {
+            console.warn('No custom editor found');
+          }
+        } catch (e) {
+          console.warn('Failed to get custom editor', e);
+        }
         if (!editorContent) {
           const defaultsEditor = state.dwServerConfig.config.defaults.editor;
           if (!defaultsEditor) {
@@ -620,6 +632,7 @@ export const actionCreators: ActionCreators = {
           const response = await getEditor(defaultsEditor, dispatch, getState, pluginRegistryUrl);
           if (response.content) {
             editorContent = response.content;
+            editorYamlUrl = response.editorYamlUrl;
           } else {
             throw new Error(response.error);
           }
@@ -653,13 +666,20 @@ export const actionCreators: ActionCreators = {
         if (devWorkspaceTemplateResource === undefined) {
           throw new Error('Failed to find a DevWorkspaceTemplate in the fetched resources.');
         }
+        if (editorYamlUrl && devWorkspaceTemplateResource.metadata) {
+          if (!devWorkspaceTemplateResource.metadata.annotations) {
+            devWorkspaceTemplateResource.metadata.annotations = {};
+          }
+          devWorkspaceTemplateResource.metadata.annotations[COMPONENT_UPDATE_POLICY] = 'managed';
+          devWorkspaceTemplateResource.metadata.annotations[REGISTRY_URL] = editorYamlUrl;
+        }
       } catch (e) {
         const errorMessage = common.helpers.errors.getMessage(e);
         dispatch({
           type: Type.RECEIVE_DEVWORKSPACE_ERROR,
           error: errorMessage,
         });
-        throw errorMessage;
+        throw e;
       }
 
       await dispatch(
