@@ -22,13 +22,13 @@ import { State as BrandingState } from '../Branding';
 import { DevWorkspaceResources, State as DevfileRegistriesState } from '../DevfileRegistries';
 import { RegistryEntry } from '../DockerConfig/types';
 import { ConvertedState, ResolverState, State as FactoryResolverState } from '../FactoryResolver';
+import { IGitOauth } from '../GitOauthConfig/types';
 import { State as InfrastructureNamespaceState } from '../InfrastructureNamespaces';
 import { State as PluginsState } from '../Plugins/chePlugins';
-import { State as UserProfileState } from '../UserProfile';
+import { State as LogsState } from '../Pods/Logs';
+import { State as UserProfileState } from '../User/Profile';
 import { State as WorkspacesState } from '../Workspaces';
 import mockThunk from './thunk';
-import { IGitOauth } from '../GitOauthConfig/types';
-import { State as LogsState } from '../Pods/Logs';
 
 export class FakeStoreBuilder {
   private state: AppState = {
@@ -71,6 +71,14 @@ export class FakeStoreBuilder {
           startTimeout: 300,
         },
         cheNamespace: '',
+        devfileRegistry: {
+          disableInternalRegistry: false,
+          externalDevfileRegistries: [],
+        },
+        devfileRegistryURL: '',
+        devfileRegistryInternalURL: '',
+        pluginRegistryURL: '',
+        pluginRegistryInternalURL: '',
       } as api.IServerConfig,
     },
     clusterInfo: {
@@ -105,10 +113,6 @@ export class FakeStoreBuilder {
       startedWorkspaces: {},
       warnings: {},
     },
-    workspacesSettings: {
-      isLoading: false,
-      settings: {} as che.WorkspaceSettings,
-    },
     branding: {
       isLoading: false,
       data: {},
@@ -126,6 +130,10 @@ export class FakeStoreBuilder {
       devWorkspaceResources: {},
       schema: {},
     } as DevfileRegistriesState,
+    userId: {
+      cheUserId: '',
+      isLoading: false,
+    },
     userProfile: {
       isLoading: false,
       userProfile: {},
@@ -148,6 +156,10 @@ export class FakeStoreBuilder {
     logs: {
       logs: {},
     },
+    personalAccessToken: {
+      isLoading: false,
+      tokens: [],
+    },
   };
 
   constructor(store?: MockStoreEnhanced<AppState, ThunkDispatch<AppState, undefined, AnyAction>>) {
@@ -156,10 +168,10 @@ export class FakeStoreBuilder {
     }
   }
 
-  public withDwServerConfig(config: api.IServerConfig): FakeStoreBuilder {
+  public withDwServerConfig(config: Partial<api.IServerConfig>): FakeStoreBuilder {
     this.state.dwServerConfig = {
       isLoading: false,
-      config,
+      config: { ...this.state.dwServerConfig.config, ...config },
     };
     return this;
   }
@@ -297,17 +309,6 @@ export class FakeStoreBuilder {
     return this;
   }
 
-  public withWorkspacesSettings(
-    settings: Partial<che.WorkspaceSettings>,
-    isLoading = false,
-    error?: string,
-  ): FakeStoreBuilder {
-    this.state.workspacesSettings.settings = Object.assign({}, settings as che.WorkspaceSettings);
-    this.state.workspacesSettings.isLoading = isLoading;
-    this.state.workspacesSettings.error = error;
-    return this;
-  }
-
   public withDevWorkspaces(
     options: {
       workspaces?: devfileApi.DevWorkspace[];
@@ -414,6 +415,23 @@ export class FakeStoreBuilder {
     return this;
   }
 
+  public withPersonalAccessTokens(
+    options: { tokens: api.PersonalAccessToken[]; error?: string },
+    isLoading = false,
+  ) {
+    this.state.personalAccessToken.tokens = Object.assign([], options.tokens);
+    this.state.personalAccessToken.error = options.error;
+    this.state.personalAccessToken.isLoading = isLoading;
+    return this;
+  }
+
+  public withCheUserId(options: { cheUserId: string; error?: string }, isLoading = false) {
+    this.state.userId.cheUserId = options.cheUserId;
+    this.state.userId.error = options.error;
+    this.state.userId.isLoading = isLoading;
+    return this;
+  }
+
   public build(): MockStoreEnhanced<AppState, ThunkDispatch<AppState, undefined, AnyAction>> {
     const middlewares = [mockThunk];
     const mockStore = createMockStore<AppState>(middlewares);
