@@ -70,18 +70,6 @@ const config = {
   },
   module: {
     rules: [
-      {
-        test: /\.tsx?$/,
-        enforce: 'pre',
-        include: path.join(__dirname, 'src'),
-        exclude: /node_modules/,
-        use: [{
-          loader: 'eslint-loader',
-          options: {
-            cache: true,
-          }
-        }],
-      },
       {
         test: /\.tsx?$/,
         include: path.join(__dirname, 'src'),
